@@ -147,8 +147,7 @@ class PluginFailed(object):
             if item:
                 entry.reject('Has already failed %s times in the past' % item.count)
 
-    @plugin.priority(-255)
-    def on_task_output(self, task, config):
+    def on_task_learn(self, task, config):
         if config is False:
             return
         config = self.prepare_config(config)
